<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>AboutDialog</name>
    <message>
        <source>About iTALC</source>
        <translation>Über iTALC</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Über</translation>
    </message>
    <message>
        <source>&lt;a href=&quot;http://italc.sourceforge.net&quot;&gt;http://italc.sourceforge.net&lt;/a&gt;</source>
        <translation>&lt;a href=&quot;http://italc.sourceforge.net&quot;&gt;http://italc.sourceforge.net&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Authors</source>
        <translation>Autoren</translation>
    </message>
    <message>
        <source>Translation</source>
        <translation>Übersetzung</translation>
    </message>
    <message>
        <source>Current language not translated yet (or native English).

If you&apos;re interested in translating iTALC into your local or another language or want to improve an existing translation, please contact an iTALC developer!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>License</source>
        <translation>Lizenz</translation>
    </message>
    <message>
        <source>iTALC - Intelligent Teaching And Learning with Computers

Copyright © 2004-2013 Tobias Doerffel / iTALC Solutions</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AccessDialogSlave</name>
    <message>
        <source>Never for this session</source>
        <translation>Nie für diese Sitzung</translation>
    </message>
    <message>
        <source>Always for this session</source>
        <translation>Immer für diese Sitzung</translation>
    </message>
    <message>
        <source>Confirm desktop access</source>
        <translation>Arbeitsflächenzugriff bestätigen</translation>
    </message>
    <message>
        <source>The user %1 at host %2 wants to access your desktop. Do you want to grant access?</source>
        <translation>Der Nutzer %1 am Rechner %2 möchte auf Ihre Arbeitsfläche zugreifen. Wollen Sie ihm Zugriff gewähren?</translation>
    </message>
</context>
<context>
    <name>ClassroomManager</name>
    <message>
        <source>Classroom-Manager</source>
        <translation>Klassenraum-Verwaltung</translation>
    </message>
    <message>
        <source>Use this workspace to manage your computers and classrooms in an easy way.</source>
        <translation>Nutzen Sie diesen Arbeitsbereich, um Ihre Computer und Klassenräume auf eine einfache Art und Weise zu verwalten.</translation>
    </message>
    <message>
        <source>This is where computers and classrooms are managed. You can add computers or classrooms by clicking right in this list.</source>
        <translation>An dieser Stelle werden Computer und Klassenräume verwaltet. Sie können Computer oder Klassenräume hinzufügen, indem Sie mit der rechten Maustaste in die Liste klicken.</translation>
    </message>
    <message>
        <source>Classrooms/computers</source>
        <translation>Klassenräume/Computer</translation>
    </message>
    <message>
        <source>IP-address</source>
        <translation>IP-Adresse</translation>
    </message>
    <message>
        <source>Usernames</source>
        <translation>Nutzernamen</translation>
    </message>
    <message>
        <source>Show usernames</source>
        <translation>Nutzernamen anzeigen</translation>
    </message>
    <message>
        <source>Use the context-menu (right mouse-button) to add/remove computers and/or classrooms.</source>
        <translation>Benutzen Sie das Kontextmenü (rechte Maustaste), um Computer und Klassenräume hinzuzufügen/zu entfernen.</translation>
    </message>
    <message>
        <source>Export to text-file</source>
        <translation>In Text-Datei exportieren</translation>
    </message>
    <message>
        <source>Use this button for exporting this list of computers and usernames into a text-file. You can use this file later for collecting files after an exam has finished. This is sometimes necessary, because some users might have finished and logged out earlier and so you cannot collect their files at the end of the exam.</source>
        <translation>Benutzen Sie diesen Button, um diese Liste mit Computern und Nutzernamen in eine Textdatei zu exportieren. Sie können diese Datei später verwenden, um z.B. nach einer Leistungsüberprüfung Dateien einzusammeln. Das ist manchmal nötig, da einige Benutzer möglicherweise früher fertig waren und sich abgemeldet haben, so dass Sie deren Dateien nicht am Ende der Leistungsüberprüfung einsammeln können.</translation>
    </message>
    <message>
        <source>Hide teacher computers</source>
        <translation>Lehrercomputer ausblenden</translation>
    </message>
    <message>
        <source>Show/hide</source>
        <translation>Zeigen/verstecken</translation>
    </message>
    <message>
        <source>Edit settings</source>
        <translation>Einstellungen bearbeiten</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Entfernen</translation>
    </message>
    <message>
        <source>Show all computers in classroom</source>
        <translation>Zeige alle Computer im Klassenraum</translation>
    </message>
    <message>
        <source>Hide all computers in classroom</source>
        <translation>Verstecke alle Computer im Klassenraum</translation>
    </message>
    <message>
        <source>Edit name</source>
        <translation>Name bearbeiten</translation>
    </message>
    <message>
        <source>Remove classroom</source>
        <translation>Klassenraum entfernen</translation>
    </message>
    <message>
        <source>Add computer</source>
        <translation>Computer hinzufügen</translation>
    </message>
    <message>
        <source>Add classroom</source>
        <translation>Klassenraum hinzufügen</translation>
    </message>
    <message>
        <source>No configuration-file found</source>
        <translation>Keine Konfigurationsdatei gefunden</translation>
    </message>
    <message>
        <source>Could not open configuration file %1.
You will have to add at least one classroom and computers using the classroom-manager which you&apos;ll find inside the program in the sidebar on the left side.</source>
        <translation>Konnte die Konfigurationsdatei %1 nicht finden. Sie werden mindestens einen Klassenraum sowie Computer mit Hilfe der Klassenraum-Verwaltung hinzufügen müssen. Sie finden die Klassenraum-Verwaltung innerhalb des Programms in der Seitenleiste auf der linken Seite.</translation>
    </message>
    <message>
        <source>Error in configuration-file</source>
        <translation>Fehler in der Konfigurationsdatei</translation>
    </message>
    <message>
        <source>Error while parsing configuration-file %1.
Please edit it. Otherwise you should delete this file and have to add all classrooms and computers again.</source>
        <translation>Fehler beim Parsen der Konfigurationsdatei %1.Bitte bearbeiten Sie sie. Andernfalls müssen Sie die Datei löschen und alle Klassenräume und Computer erneut hinzufügen.</translation>
    </message>
    <message>
        <source>Error while parsing configuration-file %1.
Please edit it. Otherwise you should delete this file.</source>
        <translation>Fehler beim Parsen der Konfigurationsdatei %1.
Bitte bearbeiten Sie diese Datei. Andernfalls sollten Sie sie löschen.</translation>
    </message>
    <message>
        <source>Select output-file</source>
        <translation>Ausgabe-Datei wählen</translation>
    </message>
    <message>
        <source>Text files (*.txt)</source>
        <translation>Textdateien (*.txt)</translation>
    </message>
    <message>
        <source>Actions for selected</source>
        <translation>Aktionen für ausgewählte</translation>
    </message>
    <message>
        <source>Actions</source>
        <translation>Aktionen</translation>
    </message>
    <message>
        <source>Actions for %1</source>
        <translation>Aktionen für %1</translation>
    </message>
    <message>
        <source>New name for classroom</source>
        <translation>Neuer Name für Klassenraum</translation>
    </message>
    <message>
        <source>Please enter a new name for classroom &quot;%1&quot;.</source>
        <translation>Bitte geben Sie einen neuen Namen für den Klassenraum &quot;%1&quot; ein.</translation>
    </message>
    <message>
        <source>Are you sure want to remove classroom &quot;%1&quot;?
All computers in it will be removed as well!</source>
        <translation>Sind Sie sicher, dass Sie den Klassenraum &quot;%1&quot; entfernen wollen?
Alle darin befindlichen Computer werden ebenfalls gelöscht!</translation>
    </message>
    <message>
        <source>Missing classroom</source>
        <translation>Fehlender Klassenraum</translation>
    </message>
    <message>
        <source>Before adding computers you have to create at least one classroom.
Do you want to create a new classrom now?</source>
        <translation>Bevor Sie Computer hinzufügen können, müssen Sie mindestens einen Klassenraum erstellen.
Möchten Sie jetzt einen neuen Klassenraum erstellen?</translation>
    </message>
    <message>
        <source>New classroom</source>
        <translation>Neuer Klassenraum</translation>
    </message>
    <message>
        <source>Please enter the name of the classroom you want to create.</source>
        <translation>Bitten geben Sie den Namen des zu erstellenden Klassenraums ein.</translation>
    </message>
</context>
<context>
    <name>Client</name>
    <message>
        <source>Unknown state</source>
        <translation>Unbekannter Zustand</translation>
    </message>
    <message>
        <source>No user logged in</source>
        <translation>Kein Benutzer angemeldet</translation>
    </message>
    <message>
        <source>Host unreachable</source>
        <translation>Rechner nicht erreichbar</translation>
    </message>
    <message>
        <source>Demo running</source>
        <translation>Demo läuft</translation>
    </message>
    <message>
        <source>Desktop locked</source>
        <translation>Arbeitsfläche gesperrt</translation>
    </message>
</context>
<context>
    <name>ClientAction</name>
    <message>
        <source>Are you sure want logout all users on all visible computers ?</source>
        <translation>Sind Sie sicher, dass Sie alle Nutzer an allen sichtbaren Computern abmelden wollen?</translation>
    </message>
    <message>
        <source>Are you sure want logout all users on all selected computers ?</source>
        <translation>Sind Sie sicher, dass Sie alle Nutzer auf allen markierten Computern abmelden wollen?</translation>
    </message>
    <message>
        <source>Logout user</source>
        <translation>Nutzer abmelden</translation>
    </message>
    <message>
        <source>Are you sure want to reboot all visible computers?</source>
        <translation>Sind Sie sicher, dass Sie alle sichtbaren Computer neustarten wollen?</translation>
    </message>
    <message>
        <source>Are you sure want to reboot all selected computers?</source>
        <translation>Sind Sie sicher, dass Sie alle gewählten Computer neustarten wollen?</translation>
    </message>
    <message>
        <source>Reboot computers</source>
        <translation>Computer neustarten</translation>
    </message>
    <message>
        <source>Are you sure want to power down all visible computers?</source>
        <translation>Sind Sie sicher, dass Sie alle sichtbaren Computer ausschalten wollen?</translation>
    </message>
    <message>
        <source>Are you sure want to power down all selected computers?</source>
        <translation>Sind Sie sicher, dass Sie alle gewählten Computer ausschalten wollen?</translation>
    </message>
</context>
<context>
    <name>ClientSettingsDialog</name>
    <message>
        <source>Invalid MAC-address</source>
        <translation>Ungültige MAC-Adresse</translation>
    </message>
    <message>
        <source>You specified an invalid MAC-address. Either leave the field blank or enter a valid MAC-address (use &quot;:&quot; as separator!).</source>
        <translation>Sie haben eine ungültige MAC-Adresse angegeben. Entweder Sie lassen das Feld frei oder geben eine gültige MAC-Adresse ein (verwenden Sie &quot;:&quot; als Trennzeichen!).</translation>
    </message>
    <message>
        <source>Client settings</source>
        <translation>Rechner-Einstellungen</translation>
    </message>
    <message>
        <source>IP/hostname</source>
        <translation>IP/Rechnername</translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;/head&gt;&lt;body style=&quot; white-space: pre-wrap; font-family:Sans Serif; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;enter an IP-address or hostname under which iTALC can reach the client (use &apos;:&apos; for specifying an optional port-number)&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;/head&gt;&lt;body style=&quot; white-space: pre-wrap; font-family:Sans Serif; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Geben Sie eine IP-Adresse oder den Rechnernamen an, unter dem iTALC den Client erreichen kann (benutzen Sie &apos;:&apos; um eine optionale Portnummer anzugeben)&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Name</translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;/head&gt;&lt;body style=&quot; white-space: pre-wrap; font-family:Sans Serif; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Optional nickname of the host which is displayed in iTALC.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>MAC address</source>
        <translation>MAC-Adresse</translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;/head&gt;&lt;body style=&quot; white-space: pre-wrap; font-family:Sans Serif; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Hardware/MAC-address of client - only used for powering on client&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;/head&gt;&lt;body style=&quot; white-space: pre-wrap; font-family:Sans Serif; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Hardware/MAC-Adresse des Rechners - wird nur zum Anschalten des Rechners benötigt&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>Classroom</source>
        <translation>Klassenraum</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Typ</translation>
    </message>
    <message>
        <source>Student computer</source>
        <translation>Schülerrechner</translation>
    </message>
    <message>
        <source>Teacher computer</source>
        <translation>Lehrercomputer</translation>
    </message>
    <message>
        <source>Other/undefined computer</source>
        <translation>Anderer/undefinierter Computer</translation>
    </message>
    <message>
        <source>Missing IP address/hostname</source>
        <translation>Fehlende IP-Adresse/Rechnername</translation>
    </message>
    <message>
        <source>You didn&apos;t specify an IP address or hostname for the computer!</source>
        <translation>Sie haben keine IP-Adresse oder keinen Rechnernamen für den Rechner angegeben!</translation>
    </message>
</context>
<context>
    <name>Config</name>
    <message>
        <source>Interval between updates</source>
        <translation>Aktualisierungsintervall</translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;/head&gt;&lt;body style=&quot; white-space: pre-wrap; font-family:Sans Serif; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Here you can set the interval between updates of clients. Higher values result in lower network-traffic and lower CPU-usage on this computer.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;/head&gt;&lt;body style=&quot; white-space: pre-wrap; font-family:Sans Serif; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Hier können Sie den Aktualisierungsinterval für die Clients setzen. Höhere Werte resultieren in geringerer Netzlast und geringerer Prozessorbelastung auf diesem Computer.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source> seconds</source>
        <translation> Sekunden</translation>
    </message>
    <message>
        <source>User interface</source>
        <translation>Benutzeroberfläche</translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;/head&gt;&lt;body style=&quot; white-space: pre-wrap; font-family:Sans Serif; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Do not show balloon-tooltips for toolbar-buttons&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;/head&gt;&lt;body style=&quot; white-space: pre-wrap; font-family:Sans Serif; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Check this option if you&apos;re annoyed by the balloon-tooltips appearing when moving mouse-cursor over toolbar-buttons.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No balloon-tooltips</source>
        <translation>Keine Ballon-Tooltips</translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;/head&gt;&lt;body style=&quot; white-space: pre-wrap; font-family:Sans Serif; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Do not show texts on toolbar-buttons&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No texts on toolbar-buttons</source>
        <translation>Kein Text auf Buttons der Werkzeugleiste</translation>
    </message>
    <message>
        <source>Your role (needs according keys!)</source>
        <translation>Ihre Rolle (entspr. Schlüssel nötig!)</translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Here you can select your role. Only change this if you know what you&apos;re doing. Otherwise you won&apos;t be able to access any clients until you restore your old role.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished">&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Hier können Sie Ihre Rolle setzen. Ändern Sie diese nur, wenn Sie wissen, was sie tun! Anderenfalls werden Sie auf keine Computer zugreifen können, bis Sie ihre alte Rolle wieder hergestellt haben.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>Teacher</source>
        <translation>Lehrer</translation>
    </message>
    <message>
        <source>Administrator</source>
        <translation>Administrator</translation>
    </message>
    <message>
        <source>Supporter</source>
        <translation>Support-Mitarbeiter</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>Andere</translation>
    </message>
    <message>
        <source>Settings for multi-logon</source>
        <translation>Einstellungen für Mehrfach-Anmeldung</translation>
    </message>
    <message>
        <source>Domain</source>
        <translation>Domäne</translation>
    </message>
    <message>
        <source>Double-click action for client-window</source>
        <translation>Doppelklick-Aktion für Client-Fenster</translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Here you can set what should happen if you double-click a client-window.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remote control</source>
        <translation>Fernsteuern</translation>
    </message>
    <message>
        <source>View live in fullscreen</source>
        <translation>Live im Vollbild anschauen</translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;/head&gt;&lt;body style=&quot; white-space: pre-wrap; font-family:Sans Serif; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:8pt; font-style:italic;&quot;&gt;Please note, that some changes won&apos;t take effect until you restart iTALC.&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;/head&gt;&lt;body style=&quot; white-space: pre-wrap; font-family:Sans Serif; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:8pt; font-style:italic;&quot;&gt;Bitte beachten Sie, dass einige Änderungen erst wirksam werden, wenn Sie iTALC neustarten.&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>Language:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>System default</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>ar - العربية</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>cs - Česky</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>de - Deutsch</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>el - Ελληνικά</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>es - Español</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>fi - Suomi</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>fr - Français</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>he - עִבְרִית</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>hu - Magyar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>it - Italiano</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>nl - Nederlands</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>nn - Norsk</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>pl - Polski</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>pt_br - Brasileiro</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>pt_pt - Português</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>ru - Русский</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>sk - Slovenský</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>sl - Slovenčina</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>sv - Svenska</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>tr - Türkçe</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>uk - Українська</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>zh_cn - 简体字</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>zh_tw - 簡體字</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ConfigWidget</name>
    <message>
        <source>Your iTALC-configuration</source>
        <translation>Ihre iTALC-Konfiguration</translation>
    </message>
    <message>
        <source>In this workspace you can customize iTALC to fit your needs.</source>
        <translation>In diesem Arbeitsbereich können Sie iTALC Ihren Bedürfnissen anpassen.</translation>
    </message>
</context>
<context>
    <name>DecoratedMessageBox</name>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>DemoClient</name>
    <message>
        <source>iTALC Demo</source>
        <translation>iTALC Demo</translation>
    </message>
</context>
<context>
    <name>ItalcCoreServer</name>
    <message>
        <source>Authentication error</source>
        <translation>Authentifizierungsfehler</translation>
    </message>
    <message>
        <source>Somebody (IP: %1) tried to access this computer but could not authenticate itself successfully!</source>
        <translation>Jemand (IP:%1) hat versucht, auf diesen Computer zuzugreifen, konnte sich jedoch nicht erfolgreich authentifizieren!</translation>
    </message>
</context>
<context>
    <name>ItalcVncConnection</name>
    <message>
        <source>VNC authentication failed because of too many authentication tries.</source>
        <translation>VNC-Authentifizierung aufgrund zu häufiger Versuche fehlgeschlagen.</translation>
    </message>
    <message>
        <source>VNC authentication failed.</source>
        <translation>VNC-Authentifizierung fehlgeschlagen.</translation>
    </message>
    <message>
        <source>VNC server closed connection.</source>
        <translation>VNC-Server hat die Verbindung geschlossen.</translation>
    </message>
</context>
<context>
    <name>KeyFileAssistant</name>
    <message>
        <source>iTALC Access Key Assistant</source>
        <translation>iTALC-Schlüsselassistent</translation>
    </message>
    <message>
        <source>Create/import iTALC access keys</source>
        <translation>iTALC-Schlüssel erzeugen/importieren</translation>
    </message>
    <message>
        <source>This assistant will help you to create or import iTALC access keys.</source>
        <translation>Dieser Assistent wird Ihnen dabei helfen, iTALC-Schlüssel zu erstellen oder importieren.</translation>
    </message>
    <message>
        <source>How does it work?</source>
        <translation>Wie funktioniert&apos;s?</translation>
    </message>
    <message>
        <source>iTALC access keys consist of two parts belonging together, a private and a public key part.

Using the private key part, users on the master computer will be able to access client computers. It is important that only authorized users have read access to the private key file.

The public key part is used on the client computers to verify that any incoming connection request is authorized.</source>
        <translation>iTALC-Zugriffsschlüssel bestehen aus zwei zueinander gehörigen Teilen, einem privaten und einem öffentlichen Schlüsselteil.

Mit Hilfe des privaten Schlüssels können Nutzer auf dem Mastercomputer auf Clientcomputer zugreifen. Es ist wichtig, dass nur autorisierte Nutzer Lesezugriff auf die private Schlüsseldatei besitzen.

Der öffentliche Schlüssel wird auf den Clientcomputern genutzt, um für jede eingehende Verbindungsanfrage zu prüfen, ob diese autorisiert ist.</translation>
    </message>
    <message>
        <source>Assistant mode</source>
        <translation>Assistentmodus</translation>
    </message>
    <message>
        <source>Please choose whether to create new access keys or import a public key on a client.</source>
        <translation>Bitte wählen Sie, ob neue Schlüssel erzeugt oder ein öffentlicher Schlüssel auf einen Client importiert werden soll.</translation>
    </message>
    <message>
        <source>Create new access keys (master computer)</source>
        <translation>Neue Schlüssel erzeugen (Master-Computer)</translation>
    </message>
    <message>
        <source>assistantModeButtonGroup</source>
        <translation></translation>
    </message>
    <message>
        <source>Import public key (client computer)</source>
        <translation>Öffentlichen Schlüssel importieren (Client-Computer)</translation>
    </message>
    <message>
        <source>Select user role</source>
        <translation>Nutzerrolle auswählen</translation>
    </message>
    <message>
        <source>Please select a user role for which to create or import the access keys:</source>
        <translation>Bitte wählen Sie eine Nutzerrolle, für die die Schlüssel erzeugt oder importiert werden sollen:</translation>
    </message>
    <message>
        <source>Teacher</source>
        <translation>Lehrer</translation>
    </message>
    <message>
        <source>Administrator</source>
        <translation>Administrator</translation>
    </message>
    <message>
        <source>Support team member</source>
        <translation>Supportmitarbeiter</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>Andere</translation>
    </message>
    <message>
        <source>User roles allow using multiple access keys in parallel. For example there can be different teacher access keys for each classroom while the support access keys are the same for the whole school.</source>
        <translation>Nutzerrollen erlauben die gleichzeitige Verwendung von mehreren Zugriffsschlüsseln. Beispielsweise können verschiedene Lehrerschlüssel für jeden Klassenraum eingerichtet werden, während die Zugriffsschlüssel für den Support schulweit einmalig sind.</translation>
    </message>
    <message>
        <source>Directories</source>
        <translation>Verzeichnisse</translation>
    </message>
    <message>
        <source>Export public key part (master computer)</source>
        <translation>Öffentlichen Schlüssel exportieren (Mastercomputer)</translation>
    </message>
    <message>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <source>Use custom destination directory for access keys</source>
        <translation>Benutzerdefiniertes Zielverzeichnis für Zugriffsschlüssel verwenden</translation>
    </message>
    <message>
        <source>Please specify the location of the public access key to be imported.</source>
        <translation>Bitte geben Sie den Ort des öffentlichen Zugriffsschlüssels an, der importiert werden soll.</translation>
    </message>
    <message>
        <source>Summary</source>
        <translation>Zusammenfassung</translation>
    </message>
    <message>
        <source>The following actions will be taken:</source>
        <translation>Die folgenden Aktionen werden durchgeführt:</translation>
    </message>
    <message>
        <source>• Create new access keys</source>
        <translation>• Neue Zugriffsschlüssel erzeugen</translation>
    </message>
    <message>
        <source>• Import public access key from</source>
        <translation>• Öffentlichen Zugriffsschlüssel exportieren aus</translation>
    </message>
    <message>
        <source>&lt;unknown&gt;</source>
        <translation>&lt;unbekannt&gt;</translation>
    </message>
    <message>
        <source>• Write access key(s) to</source>
        <translation>• Zugriffsschlüssel schreiben nach</translation>
    </message>
    <message>
        <source>• Export public key to</source>
        <translation>• Öffentlichen Schlüssel exportieren nach</translation>
    </message>
    <message>
        <source>• Configure for user role</source>
        <translation>• Konfigurieren für Nutzerrolle</translation>
    </message>
    <message>
        <source>Select directory in which to export the public key</source>
        <translation>Verzeichnis wählen, in welches der öffentliche Schlüssel exportiert werden soll</translation>
    </message>
    <message>
        <source>Key files (*.key.txt)</source>
        <translation>Schlüsseldateien (*.key.txt)</translation>
    </message>
    <message>
        <source>Invalid public key</source>
        <translation>Ungültiger öffentlicher Schlüssel</translation>
    </message>
    <message>
        <source>The selected file does not contain a valid public iTALC access key!</source>
        <translation>Die gewählte Datei beinhaltet keinen gültigen öffentliche iTALC-Zugrifsschlüssel!</translation>
    </message>
    <message>
        <source>Select destination directory</source>
        <translation>Zielverzeichnis auswählen</translation>
    </message>
    <message>
        <source>Access key creation</source>
        <translation>Erstellung des Zugriffschlüssels</translation>
    </message>
    <message>
        <source>Could not remove previously existing file %1.</source>
        <translation>Konnte bereits existierende Datei %1 nicht löschen.</translation>
    </message>
    <message>
        <source>Failed exporting public access key from %1 to %2.</source>
        <translation>Der Export des öffentlichen Zugrifsschlüssels von %1 nach %2 ist fehlgeschlagen.</translation>
    </message>
    <message>
        <source>Access keys were created and written successfully to %1 and %2.</source>
        <translation>Zugrifsschlüssel wurden erfolgreich erstellt und nach %1 und %2 geschrieben.</translation>
    </message>
    <message>
        <source>An error occured while creating the access keys. You probably are not permitted to write to the selected directories.</source>
        <translation>Beim erstellen der Zugrifsschlüssel ist ein Fehler aufgetreten. Sie sind wahrscheinlich nicht berechtigt, in die gewählten Verzeichnisse zu schreiben.</translation>
    </message>
    <message>
        <source>Public key import</source>
        <translation>Import des öffentlichen Schlüssels</translation>
    </message>
    <message>
        <source>An error occured while importing the public access key. You probably are not permitted to read the source key or to write the destination file.</source>
        <translation>Beim importieren des öffentlichen Zugrifsschlüssels ist ein Fehler aufgetreten. Sie sind wahrscheinlich nicht berechtigt, den Quellschlüssel zu lesen oder die Zieldatei zu schreiben.</translation>
    </message>
    <message>
        <source>The public key was successfully imported to %1.</source>
        <translation>Der öffentliche Schlüssel wurde erfolgreich nach %1 importiert.</translation>
    </message>
</context>
<context>
    <name>LockWidget</name>
    <message>
        <source>screen lock</source>
        <translation>Bildschirmsperre</translation>
    </message>
</context>
<context>
    <name>LogonGroupEditor</name>
    <message>
        <source>Logon group editor</source>
        <translation>Anmeldungsgruppeneditor</translation>
    </message>
    <message>
        <source>Please add the groups whose members should be allowed to access computers in your iTALC network.</source>
        <translation>Bitte fügen Sie die Gruppen hinzu, deren Mitgliedern der Zugriff auf Computern in Ihrem iTALC-Netzwerk gestattet sein soll.</translation>
    </message>
    <message>
        <source>All groups</source>
        <translation>Alle Gruppen</translation>
    </message>
    <message>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <source>Groups with iTALC privileges</source>
        <translation>Gruppen mit iTALC-Privilegien</translation>
    </message>
</context>
<context>
    <name>MainToolBar</name>
    <message>
        <source>Actions</source>
        <translation>Aktionen</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>General</source>
        <translation>Allgemein</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Beenden</translation>
    </message>
    <message>
        <source>iTALC Management Console</source>
        <translation>iTALC Management Console</translation>
    </message>
    <message>
        <source>iTALC Server</source>
        <translation>iTALC-Server</translation>
    </message>
    <message>
        <source>Paths</source>
        <translation>Pfade</translation>
    </message>
    <message>
        <source>Authentication</source>
        <translation>Authentifizierung</translation>
    </message>
    <message>
        <source>iTALC Service</source>
        <translation>iTALC-Dienst</translation>
    </message>
    <message>
        <source>Hide tray icon</source>
        <translation>Icon im Systemabschnitt verstecken</translation>
    </message>
    <message>
        <source>Autostart</source>
        <translation>Autostart</translation>
    </message>
    <message>
        <source>Additional arguments</source>
        <translation>Zusätzliche Argumente</translation>
    </message>
    <message>
        <source>Start service</source>
        <translation>Dienst starten</translation>
    </message>
    <message>
        <source>Stop service</source>
        <translation>Dienst stoppen</translation>
    </message>
    <message>
        <source>State:</source>
        <translation>Status:</translation>
    </message>
    <message>
        <source>Stopped</source>
        <translation>Beendet</translation>
    </message>
    <message>
        <source>Logging</source>
        <translation>Logaufzeichnung</translation>
    </message>
    <message>
        <source>Log file directory</source>
        <translation>Logdateiverzeichnis</translation>
    </message>
    <message>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <source>Log level</source>
        <translation>Loglevel</translation>
    </message>
    <message>
        <source>Nothing</source>
        <translation>Nichts</translation>
    </message>
    <message>
        <source>Only critical messages</source>
        <translation>Nur kritische Nachrichten</translation>
    </message>
    <message>
        <source>Errors and critical messages</source>
        <translation>Fehler und kritische Nachrichten</translation>
    </message>
    <message>
        <source>Warnings and errors</source>
        <translation>Warnungen und Fehler</translation>
    </message>
    <message>
        <source>Information, warnings and errors</source>
        <translation>Informationen, Warnungen und Fehler</translation>
    </message>
    <message>
        <source>Debug messages and everything else</source>
        <translation>Debugmeldungen und alles andere</translation>
    </message>
    <message>
        <source>Limit log file size</source>
        <translation>Logdateigröße begrenzen</translation>
    </message>
    <message>
        <source>MB</source>
        <translation>MB</translation>
    </message>
    <message>
        <source>Clear all log files</source>
        <translation>Alle Logdateien leeren</translation>
    </message>
    <message>
        <source>Desktop capturing</source>
        <translation>Bildschirmaufzeichnung</translation>
    </message>
    <message>
        <source>Enable capturing of layered (semi-transparent) windows</source>
        <translation>Halbdurchsichtige Fenster (layered windows) aufzeichnen</translation>
    </message>
    <message>
        <source>Low accuracy (turbo mode)</source>
        <translation>Niedrige Genauigkeit (Turbomodus)</translation>
    </message>
    <message>
        <source>Demo server</source>
        <translation>Demoserver</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Netzwerk</translation>
    </message>
    <message>
        <source>Core server port</source>
        <translation>Core-Server-Port</translation>
    </message>
    <message>
        <source>Demo server port</source>
        <translation>Demoserver-Port</translation>
    </message>
    <message>
        <source>Enable firewall exception</source>
        <translation>Firewall-Ausnahme aktivieren</translation>
    </message>
    <message>
        <source>Configuration files</source>
        <translation>Konfigurationsdateien</translation>
    </message>
    <message>
        <source>Global configuration</source>
        <translation>Globale Konfiguration</translation>
    </message>
    <message>
        <source>Personal configuration</source>
        <translation>Persönliche Konfiguration</translation>
    </message>
    <message>
        <source>Data directories</source>
        <translation>Datenverzeichnisse</translation>
    </message>
    <message>
        <source>Snapshots</source>
        <translation>Schnappschüsse</translation>
    </message>
    <message>
        <source>Authentication methods</source>
        <translation>Authentifizierungsmethoden</translation>
    </message>
    <message>
        <source>Access key management</source>
        <translation>Schlüsselverwaltung</translation>
    </message>
    <message>
        <source>Logon settings</source>
        <translation>Anmeldeeinstellungen</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Datei</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Hilfe</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Beenden</translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation>Strg+Q</translation>
    </message>
    <message>
        <source>&amp;Save settings into file</source>
        <translation>Einstellungen in Datei &amp;speichern</translation>
    </message>
    <message>
        <source>Save settings into file</source>
        <translation>Einstellungen in Datei speichern</translation>
    </message>
    <message>
        <source>Ctrl+S</source>
        <translation>Strg+S</translation>
    </message>
    <message>
        <source>L&amp;oad settings from file</source>
        <translation>Einstellungen aus Datei &amp;laden</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation>Strg+O</translation>
    </message>
    <message>
        <source>About iTALC</source>
        <translation>Über iTALC</translation>
    </message>
    <message>
        <source>About Qt</source>
        <translation>Über Qt</translation>
    </message>
    <message>
        <source>MainWindow</source>
        <translation></translation>
    </message>
    <message>
        <source>toolBar</source>
        <translation></translation>
    </message>
    <message>
        <source>iTALC Management Console %1</source>
        <translation>iTALC Management Console %1</translation>
    </message>
    <message>
        <source>Running</source>
        <translation>Läuft</translation>
    </message>
    <message>
        <source>Load settings from file</source>
        <translation>Einstellungen aus Datei laden</translation>
    </message>
    <message>
        <source>XML files (*.xml)</source>
        <translation>XML-Dateien (*.xml)</translation>
    </message>
    <message>
        <source>Save settings to file</source>
        <translation>Einstellungen in Datei speichern</translation>
    </message>
    <message>
        <source>Unsaved settings</source>
        <translation>Ungespeicherte Einstellungen</translation>
    </message>
    <message>
        <source>There are unsaved settings. Quit anyway?</source>
        <translation>Einige Einstellungen sind nicht gespeichert. Trotzdem beenden?</translation>
    </message>
    <message>
        <source>Configuration not writable</source>
        <translation>Konfiguration nicht schreibbar</translation>
    </message>
    <message>
        <source>The local configuration backend reported that the configuration is not writable! Please run the iTALC Management Console with higher privileges.</source>
        <translation>Laut lokalem Konfigurationsbackend ist die Konfiguration nicht scheibbar! Bitte führen Sie die iTALC-Management-Console mit höheren Privilegien aus.</translation>
    </message>
    <message>
        <source>All settings were applied successfully.</source>
        <translation>Alle Einstellungen wurden erfolgreich angewendet.</translation>
    </message>
    <message>
        <source>An error occured while applying settings!</source>
        <translation>Beim Anwenden der Einstellungen ist ein Fehler aufgetreten!</translation>
    </message>
    <message>
        <source>iTALC</source>
        <translation>iTALC</translation>
    </message>
    <message>
        <source>No write access</source>
        <translation>Kein Schreibzugriff</translation>
    </message>
    <message>
        <source>Could not read/write or create directory %1! For running iTALC, make sure you&apos;re permitted to create or write this directory.</source>
        <translation>Konnte das Verzeichnis %1 nicht lesen/schreiben oder erstellen. Um iTALC auszuführen, stellen Sie sicher, dass Sie berechtigt sind, dieses Verzeichnis zu erzeugen oder zu beschreiben.</translation>
    </message>
    <message>
        <source>Classroom</source>
        <translation>Klassenraum</translation>
    </message>
    <message>
        <source>Switch classroom</source>
        <translation>Klassenraum wechseln</translation>
    </message>
    <message>
        <source>Click this button to open a menu where you can choose the active classroom.</source>
        <translation>Klicken Sie auf diesen Knopf, um ein Menü zu öffnen, in dem sie den aktiven Klassenraum wählen können.</translation>
    </message>
    <message>
        <source>Click on this button, to switch between classrooms.</source>
        <translation>Klicken Sie auf diesen Knopf, um zwischen Klassenräumen zu wechseln.</translation>
    </message>
    <message>
        <source>Overview mode</source>
        <translation>Übersichtsmodus</translation>
    </message>
    <message>
        <source>Overview</source>
        <translation>Übersicht</translation>
    </message>
    <message>
        <source>This is the default mode in iTALC and allows you to have an overview over all visible computers. Also click on this button for unlocking locked workstations or for leaving demo-mode.</source>
        <translation>Dies ist der Standardmodus in iTALC und ermöglicht es, einen Überblick über alle sichtbaren Computer zu bekommen. Weiterhin werden gesperrte Bildschirme entsperrt oder der Demo-Modus verlassen, wenn Sie auf diesen Knopf klicken.</translation>
    </message>
    <message>
        <source>Fullscreen demo</source>
        <translation>Vollbild-Demo</translation>
    </message>
    <message>
        <source>Fullscreen Demo</source>
        <translation>Vollbild-Demo</translation>
    </message>
    <message>
        <source>Stop Demo</source>
        <translation>Demo beenden</translation>
    </message>
    <message>
        <source>In this mode your screen is being displayed on all shown computers. Furthermore the users aren&apos;t able to do something else as all input devices are locked in this mode.</source>
        <translation>In diesem Modus wird Ihr Bildschirm auf alle angezeigte Computer übertragen. Weiterhin können die Nutzer nichts anderes machen, da in diesem Modus sämtliche Eingabegeräte gesperrt sind.</translation>
    </message>
    <message>
        <source>Window demo</source>
        <translation>Fenster-Demo</translation>
    </message>
    <message>
        <source>Window Demo</source>
        <translation>Fenster-Demo</translation>
    </message>
    <message>
        <source>In this mode your screen being displayed in a window on all shown computers. The users are able to switch to other windows and thus can continue to work.</source>
        <translation>In diesem Modus wird Ihr Bildschirm auf alle angezeigte Computer in einem Fenster übertragen. Die Nutzer sind in der Lage, zu anderen Fenstern zu wechseln und somit ihre Arbeiten fortzusetzen.</translation>
    </message>
    <message>
        <source>Lock/unlock desktops</source>
        <translation>Arbeitsflächen sperren/freigeben</translation>
    </message>
    <message>
        <source>Lock all</source>
        <translation>Alle sperren</translation>
    </message>
    <message>
        <source>Unlock all</source>
        <translation>Alle freigeben</translation>
    </message>
    <message>
        <source>To have all user&apos;s full attention you can lock their desktops using this button. In this mode all input devices are locked and the screen is black.</source>
        <translation>Um die volle Aufmerksamkeit der Nutzer zu erlangen können Sie deren Arbeitsflächen mit Hilfe dieses Knopfes sperren. In diesem Modus werden alle Eingabegeräte gesperrt und der Bildschirm ist schwarz.</translation>
    </message>
    <message>
        <source>Send text message</source>
        <translation>Text-Nachricht schicken</translation>
    </message>
    <message>
        <source>Text message</source>
        <translation>Text-Nachricht</translation>
    </message>
    <message>
        <source>Use this button to send a text message to all users e.g. to tell them new tasks etc.</source>
        <translation>Nutzen Sie diesen Knopf, um an alle Nutzer eine Text-Nachricht zu schicken, beispielsweise um ihnen neue Aufgaben mitzuteilen.</translation>
    </message>
    <message>
        <source>Power on computers</source>
        <translation>Computer anschalten</translation>
    </message>
    <message>
        <source>Power on</source>
        <translation>Anschalten</translation>
    </message>
    <message>
        <source>Click this button to power on all visible computers. This way you do not have to turn on each computer by hand.</source>
        <translation>Klicken Sie auf diesen Knopf, um alle angezeigten Computer anzuschalten. Auf diese Weise müssen Sie nicht jeden Computer einzeln per Hand einschalten.</translation>
    </message>
    <message>
        <source>Power down computers</source>
        <translation>Computer ausschalten</translation>
    </message>
    <message>
        <source>Power down</source>
        <translation>Ausschalten</translation>
    </message>
    <message>
        <source>To power down all shown computers (e.g. after the lesson has finished) you can click this button.</source>
        <translation>Um alle angezeigten Computer herunterzufahren (z.B. nach Stundenende) klicken Sie einfach auf diesen Knopf.</translation>
    </message>
    <message>
        <source>Support</source>
        <translation>Unterstützung</translation>
    </message>
    <message>
        <source>Direct support</source>
        <translation>Direkte Unterstützung</translation>
    </message>
    <message>
        <source>If you need to support someone at a certain computer you can click this button and enter the according hostname or IP afterwards.</source>
        <translation>Wenn Sie jemanden an einem bestimmten Computer unterstützen wollen, können Sie diesen Button anklicken und anschließend den entsprechenden Rechnernamen oder die IP eingeben.</translation>
    </message>
    <message>
        <source>Adjust/align</source>
        <translation>Ausrichtung</translation>
    </message>
    <message>
        <source>Adjust windows and their size</source>
        <translation>Fenster und deren Größe ausrichten</translation>
    </message>
    <message>
        <source>When clicking this button the biggest possible size for the client-windows is adjusted. Furthermore all windows are aligned.</source>
        <translation>Wenn Sie diesen Knopf anklicken, wird die größt-mögliche Größe für die Fenster eingestellt. Weiterhin werden alle Fenster ausgerichtet.</translation>
    </message>
    <message>
        <source>Auto view</source>
        <translation>Anordnung</translation>
    </message>
    <message>
        <source>Auto re-arrange windows and their size</source>
        <translation>Automatische Neuanordnung der Fenster und deren Größe</translation>
    </message>
    <message>
        <source>When clicking this button all visible windows are re-arranged and adjusted.</source>
        <translation>Wenn Sie diesen Knopf anklicken werden alle sichtbaren Fenster neu angeordnet und ausgerichtet.</translation>
    </message>
    <message>
        <source>iTALC Master Control</source>
        <translation>iTALC Master Steuerung</translation>
    </message>
    <message>
        <source>Remote control</source>
        <translation>Fernsteuern</translation>
    </message>
    <message>
        <source>Could not modify the autostart property for the iTALC Service.</source>
        <translation>Die Autostarteinstellung für den iTALC-Dienst konnte nicht geändert werden.</translation>
    </message>
    <message>
        <source>Could not modify the service arguments for the iTALC Service.</source>
        <translation>Die zusätzlichen Argumente für den iTALC-Dienst konnten nicht geändert werden.</translation>
    </message>
    <message>
        <source>Could not change the firewall configuration for the iTALC Service.</source>
        <translation>Die Firewallkonfiguration für den iTALC-Dienst konnte nicht geändert werden.</translation>
    </message>
    <message>
        <source>Debugging</source>
        <translation>Fehlersuche</translation>
    </message>
    <message>
        <source>Enable desktop switching for screen lock (experimental)</source>
        <translation>Desktopwechsel für Bildschirmsperre aktivieren (experimentell)</translation>
    </message>
    <message>
        <source>Log to standard error output</source>
        <translation>Nach Standardfehlerausgabe loggen</translation>
    </message>
    <message>
        <source>Log to Windows event log</source>
        <translation>In Windows-Ereignisanzeige loggen</translation>
    </message>
    <message>
        <source>Backend</source>
        <translation>Backend</translation>
    </message>
    <message>
        <source>VNC reflector</source>
        <translation>VNC-Reflektor</translation>
    </message>
    <message>
        <source>iTALC 1 demo server</source>
        <translation>iTALC 1 Demoserver</translation>
    </message>
    <message>
        <source>Multithreading (can be enabled when using the VNC reflector backend)</source>
        <translation>Multithreading (kann aktiviert werden, wenn das VNC-Reflektor-Backend genutzt wird)</translation>
    </message>
    <message>
        <source>Enable HTTP server which provides a JavaViewer applet</source>
        <translation>HTTP-Server aktivieren, um JavaViewer-Applet bereitzustellen</translation>
    </message>
    <message>
        <source>HTTP server port</source>
        <translation>HTTP-Serverport</translation>
    </message>
    <message>
        <source>Allow connections from localhost only</source>
        <translation>Nur Verbindungen vom lokalen Rechner erlauben</translation>
    </message>
    <message>
        <source>Key file authentication</source>
        <translation>Schlüsseldatei-Authentifizierung</translation>
    </message>
    <message>
        <source>ACL-based logon authentication</source>
        <translation>ACL-basierte Anmelde-Authentifizierung</translation>
    </message>
    <message>
        <source>Public key file base directory</source>
        <translation>Basisverzeichnis der öffentlichen Schlüsseldatei</translation>
    </message>
    <message>
        <source>Private key file base directory</source>
        <translation>Basisverzeichnis der privaten Schlüsseldatei</translation>
    </message>
    <message>
        <source>Launch key file assistant</source>
        <translation>Schlüsseldatei-Assistent starten</translation>
    </message>
    <message>
        <source>Manage permissions</source>
        <translation>Berechtigungen verwalten</translation>
    </message>
    <message>
        <source>Test</source>
        <translation>Testen</translation>
    </message>
    <message>
        <source>Access confirmation</source>
        <translation>Zugriffsbestätigung</translation>
    </message>
    <message>
        <source>You can configure iTALC to ask the user for permission to access the desktop when using certain authentication methods.</source>
        <translation>Sie können iTALC so konfigurieren, dass der Nutzer bei bestimmten Authentifizierungsmethoden um Zugriffsbestätigung gebeten wird.</translation>
    </message>
    <message>
        <source>Logon authentication</source>
        <translation>Anmelde-Authentifizierung</translation>
    </message>
    <message>
        <source>Allow same user to access desktop without confirmation</source>
        <translation>Gleichen Nutzer erlauben, ohne Bestätigung auf Arbeitsfläche zuzugreifen</translation>
    </message>
    <message>
        <source>Debugging iTALC</source>
        <translation>iTALC-Fehlersuche</translation>
    </message>
    <message>
        <source>When encountering bugs or other misbehaviour in iTALC it is important to inform the developers about them, so that the bugs can be fixed in future releases. This page allows you to submit a helpful bug report easily.

If the bug is not reproducible, skip step 1) - 3).</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1)</source>
        <translation>1)</translation>
    </message>
    <message>
        <source>Clear the logfiles in the &quot;General&quot; section.</source>
        <translation>Löschen Sie die Logdateien im Abschnitt &quot;Allgemein&quot;.</translation>
    </message>
    <message>
        <source>2)</source>
        <translation>2)</translation>
    </message>
    <message>
        <source>In the &quot;General&quot; section set the log level to &quot;Debug messages and everything else&quot;.</source>
        <translation>Setzen Sie den Loglevel im Abschnitt &quot;Allgemein&quot; auf &quot;Debugmeldungen und alles andere&quot;.</translation>
    </message>
    <message>
        <source>3)</source>
        <translation>3)</translation>
    </message>
    <message>
        <source>Repeat the actions leading to the bug or misbehaviour.</source>
        <translation>Wiederholen Sie die Handlungen, die den Fehler oder das Fehlverhalten hevorrufen.</translation>
    </message>
    <message>
        <source>4)</source>
        <translation>4)</translation>
    </message>
    <message>
        <source>Click the following button and save the file to a known location.</source>
        <translation>Klicken Sie auf den folgenden Knopf und speichern die Datei an eine bekannte Stelle.</translation>
    </message>
    <message>
        <source>Generate bug report archive</source>
        <translation>Fehlerberichtsarchiv erstellen</translation>
    </message>
    <message>
        <source>5)</source>
        <translation>5)</translation>
    </message>
    <message>
        <source>Go to the &lt;a href=&quot;http://sourceforge.net/tracker/?group_id=132465&amp;amp;atid=724375&quot;&gt;iTALC bug tracker&lt;/a&gt;, open a new bug, describe what you did in step 3) and attach the file you saved in step 4).&lt;/p&gt;
&lt;br/&gt;
&lt;br/&gt;
Note: if the bug involves both a master and client computer, attach bug report archives for both computers.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Restart iTALC Service</source>
        <translation>iTALC-Dienst neustarten</translation>
    </message>
    <message>
        <source>All settings were saved successfully. In order to take effect the iTALC service needs to be restarted. Restart it now?</source>
        <translation>Alle Einstellungen wurden erfolgreich gespeichert. Um die Änderungen anzuwenden muss der iTALC-Dienst neugestartet werden. Dienst jetzt neustarten?</translation>
    </message>
    <message>
        <source>Starting iTALC service</source>
        <translation>Starte iTALC-Dienst</translation>
    </message>
    <message>
        <source>Stopping iTALC service</source>
        <translation>Stoppe iTALC-Dienst</translation>
    </message>
    <message>
        <source>The iTALC service needs to be stopped temporarily in order to remove the log files. Continue?</source>
        <translation>Der iTALC-Dienst muss temporär gestoppt werden, um die Logdateien zu entfernen. Fortfahren?</translation>
    </message>
    <message>
        <source>Log files cleared</source>
        <translation>Logdateien gelösch</translation>
    </message>
    <message>
        <source>All log files were cleared successfully.</source>
        <translation>Alle Logdateien wurden erfolgreich gelöscht.</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Fehler</translation>
    </message>
    <message>
        <source>Could not remove all log files.</source>
        <translation>Konnte nicht alle Logdateien entfernen.</translation>
    </message>
    <message>
        <source>Logon authentication test</source>
        <translation>Test der Anmelde-Authentifizierung</translation>
    </message>
    <message>
        <source>Authentication with provided credentials was successful.</source>
        <translation>Die Authentifizierung mit den angegebenen Anmeldedaten war erfolgreich.</translation>
    </message>
    <message>
        <source>Authentication with provided credentials failed!</source>
        <translation>Die Authentifizierung mit den angegebenen Anmeldedaten ist fehlgeschlagen!</translation>
    </message>
    <message>
        <source>Save bug report archive</source>
        <translation>Fehlerberichtsarchiv speichern</translation>
    </message>
    <message>
        <source>iTALC bug report archive (*.ibra.xml)</source>
        <translation>iTALC-Fehlerberichtsarchiv (*.ibra.xml)</translation>
    </message>
    <message>
        <source>iTALC bug report archive saved</source>
        <translation>iTALC-Fehlerberichtsarchiv gespeichert</translation>
    </message>
    <message>
        <source>An iTALC bug report archive has been saved to %1. It includes iTALC log files and information about your operating system. You can attach it to a bug report.</source>
        <translation>Ein iTALC-Fehlerberichtsarchiv wurde nach %1 gespeichert. Es beinhaltet iTALC-Logdateien und Informationen über Ihre Betriebssystem. Sie können es an einen Fehlerbericht anhängen.</translation>
    </message>
    <message>
        <source>Could not contact iTALC service</source>
        <translation>Kein Kontakt zum iTALC-Dienst</translation>
    </message>
    <message>
        <source>Could not contact the local iTALC service. It is likely that you entered wrong credentials or key files are not set up properly. Try again or contact your administrator for solving this problem using the iTALC Management Console.</source>
        <translation>Es konnte keine Verbindung zum lokalen iTALC-Dienst hergestellt werden. Wahrscheinlich haben Sie falsche Anmeldedaten eingegeben oder die Schlüsseldateien sind nicht richtig eingerichtet. Versuchen SIe es erneut oder konktaktieren Sie Ihren Administrator, um das Problem mit Hilfe der iTALC-Management-Console zu lösen.</translation>
    </message>
    <message>
        <source>Authentication impossible</source>
        <translation>Authentifizierung nicht möglich</translation>
    </message>
    <message>
        <source>No authentication key files were found or your current ones are outdated. Please create new key files using the iTALC Management Console. Alternatively set up logon authentication using the iTALC Management Console. Otherwise you won&apos;t be able to access computers using iTALC.</source>
        <translation>Es wurden keine Authentifizierungsschlüsseldateien gefunden oder sie sind veraltet. Bitte erstellen Sie neue Schlüsseldateien mit Hilfe der iTALC-Management-Console. Alternativ können Sie die Anmelde-Authentifizierung mit Hilfe der iTALC-Management-Console einrichten. Andernfalls werden Sie nicht in der Lage sein, mit iTALC auf andere Rechner zuzugreifen.</translation>
    </message>
    <message>
        <source>Poll full screen (leave this enabled per default)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MessageBoxSlave</name>
    <message>
        <source>Message from teacher</source>
        <translation>Nachricht vom Lehrer</translation>
    </message>
</context>
<context>
    <name>Overview</name>
    <message>
        <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:12pt; font-weight:600; font-style:italic;&quot;&gt;Welcome to iTALC!&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:12pt; font-weight:600; font-style:italic;&quot;&gt;Willkommen bei iTALC!&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>Here you see the working-bar which contains several buttons. Each button is connected to a workspace. Just take a look at the available workspaces by clicking on the corresponding button.</source>
        <translation>Hier sehen Sie die Arbeitsleiste mit ihren verschiedenen Knöpfe. Jeder Knopf ist mit einem Arbeitsbereich verbunden. Schauen Sie sich einfach einmal die verfügbaren Arbeitsbereiche an, indem Sie auf den entsprechenden Knopf klicken.</translation>
    </message>
    <message>
        <source>Using the classroom-manager you can manage your classrooms and computers. You can also see which users are logged in.</source>
        <translation>Mit Hilfe der Klassenraum-Verwaltung können Sie Ihre Klassenräume und Computer verwalten. Sie können außerdem sehen, welche Nutzer angemeldet sind.</translation>
    </message>
    <message>
        <source>The snapshot-workspace is a very useful tool. It let&apos;s you manage the snapshots you made.</source>
        <translation>Der Schnappschuss-Arbeitsbereich ist ein sehr nützliches Werzeug, mit dem Sie ihre Schnappschüsse verwalten können.</translation>
    </message>
    <message>
        <source>Of course you can configure iTALC. This is usually done using the configuration-workspace.</source>
        <translation>Natürlich können Sie iTALC auch einrichten. Dies wird in der Regel mit dem Konfigurations-Arbeitsbereich erledigt.</translation>
    </message>
    <message>
        <source>About iTALC</source>
        <translation>Über iTALC</translation>
    </message>
</context>
<context>
    <name>OverviewWidget</name>
    <message>
        <source>Overview</source>
        <translation>Übersicht</translation>
    </message>
    <message>
        <source>Some basic information on iTALC and how to use it.</source>
        <translation>Grundlegende Informationen über iTALC und dessen Benutzung.</translation>
    </message>
</context>
<context>
    <name>PasswordDialog</name>
    <message>
        <source>Please enter your username and password in order to access iTALC clients.</source>
        <translation>Bitte geben Sie Ihren Nutzernamen und Ihr Passwort ein, um auf iTALC-Clients zugreifen zu können.</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nutzername</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Passwort</translation>
    </message>
    <message>
        <source>iTALC Logon</source>
        <translation>iTALC-Anmeldung</translation>
    </message>
    <message>
        <source>Manage</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <source>Unable to register service &apos;%1&apos;.</source>
        <translation>Der Dienst &apos;%1&apos; konnte nicht registriert werden.</translation>
    </message>
    <message>
        <source>The Service Control Manager could not be contacted (do you have the necessary rights?!) - the service &apos;%1&apos; was not registered.</source>
        <translation>Es konnte keine Verbindung zum Service-Control-Manager hergestellt werden (haben Sie die nötigen Rechte?!) - der Dienst &apos;%1&apos; wurde nicht registriert.</translation>
    </message>
    <message>
        <source>The service &apos;%1&apos; is already registered.</source>
        <translation>Der Dienst &apos;%1&apos; ist bereits registriert.</translation>
    </message>
    <message>
        <source>The service &apos;%1&apos; could not be registered.</source>
        <translation>Der Dienst &apos;%1&apos; konnte nicht registriert werden.</translation>
    </message>
    <message>
        <source>The service &apos;%1&apos; was successfully registered.</source>
        <translation>Der Dienst &apos;%1&apos; wurde erfolgreich registriert.</translation>
    </message>
    <message>
        <source>The service &apos;%1&apos; could not be stopped.</source>
        <translation>Der Dienst &apos;%1&apos; konnte nicht gestoppt werden.</translation>
    </message>
    <message>
        <source>The service &apos;%1&apos; has been unregistered.</source>
        <translation>Der Dienst &apos;%1&apos; wurde entfernt.</translation>
    </message>
    <message>
        <source>The service &apos;%1&apos; isn&apos;t registered and therefore can&apos;t be unregistered.</source>
        <translation>Der Dienst &apos;%1&apos; ist nicht registriert und kann daher nicht entfernt werden.</translation>
    </message>
    <message>
        <source>The service &apos;%1&apos; could not be unregistered.</source>
        <translation>Der Dienst &apos;%1&apos; konnte nicht entfernt werden.</translation>
    </message>
    <message>
        <source>The service &apos;%1&apos; could not be found.</source>
        <translation>Der Dienst &apos;%1&apos; wurde nicht gefunden.</translation>
    </message>
    <message>
        <source>The Service Control Manager could not be contacted (do you have the necessary rights?!) - the service &apos;%1&apos; was not unregistered.</source>
        <translation>Es konnte keine Verbindung zum Service-Control-Manager hergestellt werden (haben Sie die nötigen Rechte?!) - der Dienst &apos;%1&apos; wurde nicht entfernt.</translation>
    </message>
    <message>
        <source>The Service Control Manager could not be contacted (do you have the necessary rights?!) - the service &apos;%1&apos; was not stopped.</source>
        <translation>Es konnte keine Verbindung zum Service-Control-Manager hergestellt werden (haben Sie die nötigen Rechte?!) - der Dienst &apos;%1&apos; wurde nicht beendet.</translation>
    </message>
    <message>
        <source>iTALC Client %1 on %2:%3</source>
        <translation>iTALC Client %1 auf %2:%3</translation>
    </message>
</context>
<context>
    <name>RemoteControlWidget</name>
    <message>
        <source>View live (%1 @ %2)</source>
        <translation>Live anschauen (%1 @ %2)</translation>
    </message>
    <message>
        <source>Remote control (%1 @ %2)</source>
        <translation>Fernsteuerung (%1 @ %2)</translation>
    </message>
    <message>
        <source>unknown user</source>
        <translation>unbekannter Nutzer</translation>
    </message>
</context>
<context>
    <name>RemoteControlWidgetToolBar</name>
    <message>
        <source>View only</source>
        <translation>Nur beobachten</translation>
    </message>
    <message>
        <source>Remote control</source>
        <translation>Fernsteuern</translation>
    </message>
    <message>
        <source>Lock student</source>
        <translation>Schüler sperren</translation>
    </message>
    <message>
        <source>Unlock student</source>
        <translation>Schüler freigeben</translation>
    </message>
    <message>
        <source>Snapshot</source>
        <translation>Schnappschuss</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Vollbild</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>Fenster</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Beenden</translation>
    </message>
    <message>
        <source>Connecting %1</source>
        <translation>Verbindung wird hergestellt %1</translation>
    </message>
    <message>
        <source>Connected.</source>
        <translation>Verbindung hergestellt.</translation>
    </message>
</context>
<context>
    <name>RemoteLogonDialog</name>
    <message>
        <source>Remote logon</source>
        <translation>Ferngesteuerte Anmeldung</translation>
    </message>
    <message>
        <source>Use the fields below to enter the username, password and optional the domain name. These information will be used to logon the computer(s).</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nutzername</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Passwort</translation>
    </message>
    <message>
        <source>Domain</source>
        <translation>Domäne</translation>
    </message>
</context>
<context>
    <name>RunCommandsDialog</name>
    <message>
        <source>Run commands</source>
        <translation>Befehle ausführen</translation>
    </message>
    <message>
        <source>Please enter the commands to run on the selected client(s). You can separate multiple commands by line.</source>
        <translation>Bitte geben Sie die Befehle ein, die auf den gewählten Clients ausgeführt werden sollen. Sie können mehre Befehle zeilenweise trennen.</translation>
    </message>
</context>
<context>
    <name>Snapshot</name>
    <message>
        <source>unknown</source>
        <translation>unbekannt</translation>
    </message>
    <message>
        <source>Could not take a snapshot as directory %1 doesn&apos;t exist and couldn&apos;t be created.</source>
        <translation>Konnte keinen Schnappschuss erstellen, da das Verzeichnis %1 nicht existiert und nicht erstellt werden konnte.</translation>
    </message>
    <message>
        <source>Snapshot</source>
        <translation>Schnappschuss</translation>
    </message>
</context>
<context>
    <name>SnapshotList</name>
    <message>
        <source>Snapshots</source>
        <translation>Schnappschüsse</translation>
    </message>
    <message>
        <source>Simply manage the snapshots you made using this workspace.</source>
        <translation>Verwalten Sie Ihre Schnappschüsse mit Hilfe dieses Arbeitsbereiches.</translation>
    </message>
</context>
<context>
    <name>Snapshots</name>
    <message>
        <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;All snapshots you made are listed here. You can make snapshots by selecting the according entry in the context-menu of a client-window. These snapshosts can be managed using the buttons below.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;p, li { white-space: pre-wrap; }&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Hier sind alle Schnappschüsse aufgelistet, die Sie erstellt haben. Sie können Schnappschüsse erstellen, indem Sie den entsprechenden Eintrag im Kontextmenü eines Client-Fenster anklicken. Diese Schnappschüsse können mit Hilfe der unterhalb befindlichen Buttons verwaltet werden.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>User:</source>
        <translation>Benutzer:</translation>
    </message>
    <message>
        <source>Host:</source>
        <translation>Rechner:</translation>
    </message>
    <message>
        <source>Date:</source>
        <translation>Datum:</translation>
    </message>
    <message>
        <source>Time:</source>
        <translation>Zeit:</translation>
    </message>
    <message>
        <source>Show</source>
        <translation>Anzeigen</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Löschen</translation>
    </message>
</context>
<context>
    <name>SupportDialog</name>
    <message>
        <source>Support</source>
        <translation>Unterstützung</translation>
    </message>
    <message>
        <source>Please enter the IP address or the name of the host to which you want to connect.</source>
        <translation>Bitte geben Sie die IP-Adresse oder den Namen des Rechners an, mit dem Sie sich verbinden möchten.</translation>
    </message>
</context>
<context>
    <name>TextMessageDialog</name>
    <message>
        <source>Send text message</source>
        <translation>Text-Nachricht schicken</translation>
    </message>
    <message>
        <source>Use the field below to type your message which will be sent to all selected users.</source>
        <translation>Nutzen Sie das Feld unterhalb, um Ihre Nachricht zu tippen, die an alle Nutzer geschickt wird.</translation>
    </message>
</context>
<context>
    <name>VncView</name>
    <message>
        <source>Establishing connection to %1 ...</source>
        <translation>Verbindung zu %1 wird hergestellt ...</translation>
    </message>
</context>
<context>
    <name>clientMenu</name>
    <message>
        <source>Overview</source>
        <translation>Übersicht</translation>
    </message>
    <message>
        <source>Fullscreen demo</source>
        <translation>Vollbild-Demo</translation>
    </message>
    <message>
        <source>Window demo</source>
        <translation>Fenster-Demo</translation>
    </message>
    <message>
        <source>Locked display</source>
        <translation>Bildschirm gesperrt</translation>
    </message>
    <message>
        <source>View live</source>
        <translation>Live anschauen</translation>
    </message>
    <message>
        <source>Remote control</source>
        <translation>Fernsteuern</translation>
    </message>
    <message>
        <source>Let student show demo</source>
        <translation>Schüler Demo zeigen lassen</translation>
    </message>
    <message>
        <source>Send text message</source>
        <translation>Text-Nachricht schicken</translation>
    </message>
    <message>
        <source>Logout user</source>
        <translation>Nutzer abmelden</translation>
    </message>
    <message>
        <source>Take a snapshot</source>
        <translation>Einen Schnappschuss machen</translation>
    </message>
    <message>
        <source>Power on</source>
        <translation>Anschalten</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Neustarten</translation>
    </message>
    <message>
        <source>Power down</source>
        <translation>Ausschalten</translation>
    </message>
    <message>
        <source>Execute commands</source>
        <translation>Befehle ausführen</translation>
    </message>
</context>
</TS>
